.. _ydoc directive_1 directive_1_1:

``directive_1_1``
-----------------

  * 1
  * 2
  * 3


This is a description of Directive 1.1

----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.